@@ -1,7 +1,12 @@
 class RayaApplicationBase():
-    
+
+
+    async def sleep(self, sleep_time: float):
+    	pass
+
     async def enable_controller(self, ctlr_name: str) -> BaseController:
-        pass
+    	pass
 
+    def finish_app(self):
+    	pass
 
-    
\ No newline at end of file
